@@ -6,9 +6,9 @@ use Log::ger;
 use parent qw(Perinci::CmdLine::Lite);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-11-14'; # DATE
+our $DATE = '2023-07-11'; # DATE
 our $DIST = 'App-depak'; # DIST
-our $VERSION = '0.585'; # VERSION
+our $VERSION = '0.586'; # VERSION
 
 sub hook_before_read_config_file {
     my ($self, $r) = @_;
@@ -68,7 +68,7 @@ Perinci::CmdLine::depak - Subclass of Perinci::CmdLine::Lite to set config_profi
 
 =head1 VERSION
 
-This document describes version 0.585 of Perinci::CmdLine::depak (from Perl distribution App-depak), released on 2021-11-14.
+This document describes version 0.586 of Perinci::CmdLine::depak (from Perl distribution App-depak), released on 2023-07-11.
 
 =head1 DESCRIPTION
 
@@ -109,13 +109,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
